@@ -33,26 +33,36 @@
  */
 
 #if defined(__x86_64__) || defined(_M_X64)
-#define NEED_SCALAR_CONVERTER_FALLBACKS 0  /* x86_64 guarantees SSE2. */
-#ifndef __SSE2__ /* For some reason this is not always defined? -flibit */
-#define __SSE2__
-#endif
-#elif __MACOSX__
-#ifndef __SSE2__
-#error macOS does not have SSE2? Bad compiler? They actually moved to ARM?!
-#endif
-#define NEED_SCALAR_CONVERTER_FALLBACKS 0  /* Mac OS X/Intel guarantees SSE2. */
+	/* Some platforms fail to define this... */
+	#ifndef __SSE2__
+	#define __SSE2__ 1
+	#endif
+
+	/* x86_64 guarantees SSE2. */
+	#define NEED_SCALAR_CONVERTER_FALLBACKS 0
 #elif defined(__aarch64__) || defined(_M_ARM64)
-#define NEED_SCALAR_CONVERTER_FALLBACKS 0  /* AArch64 guarantees NEON. */
+	/* Some platforms fail to define this... */
+	#ifndef __ARM_NEON__
+	#define __ARM_NEON__ 1
+	#endif
+
+	/* AArch64 guarantees NEON. */
+	#define NEED_SCALAR_CONVERTER_FALLBACKS 0
+#elif __MACOSX__
+	/* Some build systems may need to specify this. Also, macOS ARM? Sigh */
+	#ifndef __SSE2__
+	#error macOS does not have SSE2? Bad compiler? They actually moved to ARM?!
+	#endif
+
+	/* Mac OS X/Intel guarantees SSE2. */
+	#define NEED_SCALAR_CONVERTER_FALLBACKS 0
 #else
-#define NEED_SCALAR_CONVERTER_FALLBACKS 1
+	/* Need plain C implementations to support all other hardware */
+	#define NEED_SCALAR_CONVERTER_FALLBACKS 1
 #endif
 
-/* Our NEON paths require AArch64 */
+/* Our NEON paths require AArch64, don't check __ARM_NEON__ here */
 #if defined(__aarch64__) || defined(_M_ARM64)
-#ifndef __ARM_NEON__ /* Some platforms fail to define this... */
-#define __ARM_NEON__ 1
-#endif
 #include <arm_neon.h>
 #define HAVE_NEON_INTRINSICS 1
 #endif
@@ -275,10 +285,10 @@ void FAudio_INTERNAL_Convert_U8_To_F32_NEON(
             const uint16x8_t uint16hi = vmovl_u8(vget_high_u8(bytes));  /* convert top 8 bytes to 8 uint16 */
             const uint16x8_t uint16lo = vmovl_u8(vget_low_u8(bytes));   /* convert bottom 8 bytes to 8 uint16 */
             /* split uint16 to two uint32, then convert to float, then multiply to normalize, subtract to adjust for sign, store. */
-            vst1q_f32(dst, vmlaq_f32(negone, vcvtq_f32_u32(vmovl_u16(vget_high_u16(uint16hi))), divby128));
-            vst1q_f32(dst+4, vmlaq_f32(negone, vcvtq_f32_u32(vmovl_u16(vget_low_u16(uint16hi))), divby128));
-            vst1q_f32(dst+8, vmlaq_f32(negone, vcvtq_f32_u32(vmovl_u16(vget_high_u16(uint16lo))), divby128));
-            vst1q_f32(dst+12, vmlaq_f32(negone, vcvtq_f32_u32(vmovl_u16(vget_low_u16(uint16lo))), divby128));
+            vst1q_f32(dst, vmlaq_f32(negone, vcvtq_f32_u32(vmovl_u16(vget_low_u16(uint16hi))), divby128));
+            vst1q_f32(dst+4, vmlaq_f32(negone, vcvtq_f32_u32(vmovl_u16(vget_high_u16(uint16hi))), divby128));
+            vst1q_f32(dst+8, vmlaq_f32(negone, vcvtq_f32_u32(vmovl_u16(vget_low_u16(uint16lo))), divby128));
+            vst1q_f32(dst+12, vmlaq_f32(negone, vcvtq_f32_u32(vmovl_u16(vget_high_u16(uint16lo))), divby128));
             i -= 16; mmsrc -= 16; dst -= 16;
         }
 
@@ -1182,11 +1192,6 @@ void FAudio_INTERNAL_Amplify_Scalar(
 	for (i = 0; i < totalSamples; i += 1)
 	{
 		output[i] *= volume;
-		output[i] = FAudio_clamp(
-			output[i],
-			-FAUDIO_MAX_VOLUME_LEVEL,
-			FAUDIO_MAX_VOLUME_LEVEL
-		);
 	}
 }
 #endif /* NEED_SCALAR_CONVERTER_FALLBACKS */
@@ -1202,7 +1207,7 @@ void FAudio_INTERNAL_Amplify_SSE2(
 	uint32_t i;
 	uint32_t header = (16 - (((size_t) output) % 16)) / 4;
 	uint32_t tail = (totalSamples - header) % 4;
-	__m128 volumeVec, minVolumeVec, maxVolumeVec, outVec;
+	__m128 volumeVec, outVec;
 	if (header == 4)
 	{
 		header = 0;
@@ -1215,33 +1220,19 @@ void FAudio_INTERNAL_Amplify_SSE2(
 	for (i = 0; i < header; i += 1)
 	{
 		output[i] *= volume;
-		output[i] = FAudio_clamp(
-			output[i],
-			-FAUDIO_MAX_VOLUME_LEVEL,
-			FAUDIO_MAX_VOLUME_LEVEL
-		);
 	}
 
 	volumeVec = _mm_set1_ps(volume);
-	minVolumeVec = _mm_set1_ps(-FAUDIO_MAX_VOLUME_LEVEL);
-	maxVolumeVec = _mm_set1_ps(FAUDIO_MAX_VOLUME_LEVEL);
 	for (i = header; i < totalSamples - tail; i += 4)
 	{
 		outVec = _mm_load_ps(output + i);
 		outVec = _mm_mul_ps(outVec, volumeVec);
-		outVec = _mm_max_ps(outVec, minVolumeVec);
-		outVec = _mm_min_ps(outVec, maxVolumeVec);
 		_mm_store_ps(output + i, outVec);
 	}
 
 	for (i = totalSamples - tail; i < totalSamples; i += 1)
 	{
 		output[i] *= volume;
-		output[i] = FAudio_clamp(
-			output[i],
-			-FAUDIO_MAX_VOLUME_LEVEL,
-			FAUDIO_MAX_VOLUME_LEVEL
-		);
 	}
 }
 #endif /* HAVE_SSE2_INTRINSICS */
@@ -1255,7 +1246,7 @@ void FAudio_INTERNAL_Amplify_NEON(
 	uint32_t i;
 	uint32_t header = (16 - (((size_t) output) % 16)) / 4;
 	uint32_t tail = (totalSamples - header) % 4;
-	float32x4_t volumeVec, minVolumeVec, maxVolumeVec, outVec;
+	float32x4_t volumeVec, outVec;
 	if (header == 4)
 	{
 		header = 0;
@@ -1268,33 +1259,19 @@ void FAudio_INTERNAL_Amplify_NEON(
 	for (i = 0; i < header; i += 1)
 	{
 		output[i] *= volume;
-		output[i] = FAudio_clamp(
-			output[i],
-			-FAUDIO_MAX_VOLUME_LEVEL,
-			FAUDIO_MAX_VOLUME_LEVEL
-		);
 	}
 
 	volumeVec = vdupq_n_f32(volume);
-	minVolumeVec = vdupq_n_f32(-FAUDIO_MAX_VOLUME_LEVEL);
-	maxVolumeVec = vdupq_n_f32(FAUDIO_MAX_VOLUME_LEVEL);
 	for (i = header; i < totalSamples - tail; i += 4)
 	{
 		outVec = vld1q_f32(output + i);
 		outVec = vmulq_f32(outVec, volumeVec);
-		outVec = vmaxq_f32(outVec, minVolumeVec);
-		outVec = vminq_f32(outVec, maxVolumeVec);
 		vst1q_f32(output + i, outVec);
 	}
 
 	for (i = totalSamples - tail; i < totalSamples; i += 1)
 	{
 		output[i] *= volume;
-		output[i] = FAudio_clamp(
-			output[i],
-			-FAUDIO_MAX_VOLUME_LEVEL,
-			FAUDIO_MAX_VOLUME_LEVEL
-		);
 	}
 }
 #endif /* HAVE_NEON_INTRINSICS */
@@ -1324,11 +1301,6 @@ void FAudio_INTERNAL_Mix_Generic_Scalar(
 				coefficients[co * srcChans + ci]
 			);
 		}
-		dst[co] = FAudio_clamp(
-			dst[co],
-			-FAUDIO_MAX_VOLUME_LEVEL,
-			FAUDIO_MAX_VOLUME_LEVEL
-		);
 	}
 }
 
@@ -1346,15 +1318,8 @@ void FAudio_INTERNAL_Mix_1in_1out_Scalar(
 	float totalVolume = baseVolume * channelVolume[0] * coefficients[0];
 	for (i = 0; i < toMix; i += 1, src += 1, dst += 1)
 	{
-		/* Base source data, combined with the coefficients... */
+		/* Base source data, combined with the coefficients */
 		dst[0] += src[0] * totalVolume;
-
-		/* ... then clamped. */
-		dst[0] = FAudio_clamp(
-			dst[0],
-			-FAUDIO_MAX_VOLUME_LEVEL,
-			FAUDIO_MAX_VOLUME_LEVEL
-		);
 	}
 }
 
@@ -1375,21 +1340,9 @@ void FAudio_INTERNAL_Mix_1in_2out_Scalar(
 		/* Base source data... */
 		const float sample = src[0] * totalVolume;
 
-		/* ... combined with the coefficients... */
+		/* ... combined with the coefficients. */
 		dst[0] += sample * coefficients[0];
 		dst[1] += sample * coefficients[1];
-
-		/* ... then clamped. */
-		dst[0] = FAudio_clamp(
-			dst[0],
-			-FAUDIO_MAX_VOLUME_LEVEL,
-			FAUDIO_MAX_VOLUME_LEVEL
-		);
-		dst[1] = FAudio_clamp(
-			dst[1],
-			-FAUDIO_MAX_VOLUME_LEVEL,
-			FAUDIO_MAX_VOLUME_LEVEL
-		);
 	}
 }
 
@@ -1410,45 +1363,13 @@ void FAudio_INTERNAL_Mix_1in_6out_Scalar(
 		/* Base source data... */
 		const float sample = src[0] * totalVolume;
 
-		/* ... combined with the coefficients... */
+		/* ... combined with the coefficients. */
 		dst[0] += sample * coefficients[0];
 		dst[1] += sample * coefficients[1];
 		dst[2] += sample * coefficients[2];
 		dst[3] += sample * coefficients[3];
 		dst[4] += sample * coefficients[4];
 		dst[5] += sample * coefficients[5];
-
-		/* ... then clamped. */
-		dst[0] = FAudio_clamp(
-			dst[0],
-			-FAUDIO_MAX_VOLUME_LEVEL,
-			FAUDIO_MAX_VOLUME_LEVEL
-		);
-		dst[1] = FAudio_clamp(
-			dst[1],
-			-FAUDIO_MAX_VOLUME_LEVEL,
-			FAUDIO_MAX_VOLUME_LEVEL
-		);
-		dst[2] = FAudio_clamp(
-			dst[2],
-			-FAUDIO_MAX_VOLUME_LEVEL,
-			FAUDIO_MAX_VOLUME_LEVEL
-		);
-		dst[3] = FAudio_clamp(
-			dst[3],
-			-FAUDIO_MAX_VOLUME_LEVEL,
-			FAUDIO_MAX_VOLUME_LEVEL
-		);
-		dst[4] = FAudio_clamp(
-			dst[4],
-			-FAUDIO_MAX_VOLUME_LEVEL,
-			FAUDIO_MAX_VOLUME_LEVEL
-		);
-		dst[5] = FAudio_clamp(
-			dst[5],
-			-FAUDIO_MAX_VOLUME_LEVEL,
-			FAUDIO_MAX_VOLUME_LEVEL
-		);
 	}
 }
 
@@ -1469,7 +1390,7 @@ void FAudio_INTERNAL_Mix_1in_8out_Scalar(
 		/* Base source data... */
 		const float sample = src[0] * totalVolume;
 
-		/* ... combined with the coefficients... */
+		/* ... combined with the coefficients. */
 		dst[0] += sample * coefficients[0];
 		dst[1] += sample * coefficients[1];
 		dst[2] += sample * coefficients[2];
@@ -1478,48 +1399,6 @@ void FAudio_INTERNAL_Mix_1in_8out_Scalar(
 		dst[5] += sample * coefficients[5];
 		dst[6] += sample * coefficients[6];
 		dst[7] += sample * coefficients[7];
-
-		/* ... then clamped. */
-		dst[0] = FAudio_clamp(
-			dst[0],
-			-FAUDIO_MAX_VOLUME_LEVEL,
-			FAUDIO_MAX_VOLUME_LEVEL
-		);
-		dst[1] = FAudio_clamp(
-			dst[1],
-			-FAUDIO_MAX_VOLUME_LEVEL,
-			FAUDIO_MAX_VOLUME_LEVEL
-		);
-		dst[2] = FAudio_clamp(
-			dst[2],
-			-FAUDIO_MAX_VOLUME_LEVEL,
-			FAUDIO_MAX_VOLUME_LEVEL
-		);
-		dst[3] = FAudio_clamp(
-			dst[3],
-			-FAUDIO_MAX_VOLUME_LEVEL,
-			FAUDIO_MAX_VOLUME_LEVEL
-		);
-		dst[4] = FAudio_clamp(
-			dst[4],
-			-FAUDIO_MAX_VOLUME_LEVEL,
-			FAUDIO_MAX_VOLUME_LEVEL
-		);
-		dst[5] = FAudio_clamp(
-			dst[5],
-			-FAUDIO_MAX_VOLUME_LEVEL,
-			FAUDIO_MAX_VOLUME_LEVEL
-		);
-		dst[6] = FAudio_clamp(
-			dst[6],
-			-FAUDIO_MAX_VOLUME_LEVEL,
-			FAUDIO_MAX_VOLUME_LEVEL
-		);
-		dst[7] = FAudio_clamp(
-			dst[7],
-			-FAUDIO_MAX_VOLUME_LEVEL,
-			FAUDIO_MAX_VOLUME_LEVEL
-		);
 	}
 }
 
@@ -1538,18 +1417,11 @@ void FAudio_INTERNAL_Mix_2in_1out_Scalar(
 	float totalVolumeR = baseVolume * channelVolume[1] * coefficients[1];
 	for (i = 0; i < toMix; i += 1, src += 2, dst += 1)
 	{
-		/* Base source data, combined with the coefficients... */
+		/* Base source data, combined with the coefficients */
 		dst[0] += (
 			(src[0] * totalVolumeL) +
 			(src[1] * totalVolumeR)
 		);
-
-		/* ... then clamped. */
-		dst[0] = FAudio_clamp(
-			dst[0],
-			-FAUDIO_MAX_VOLUME_LEVEL,
-			FAUDIO_MAX_VOLUME_LEVEL
-		);
 	}
 }
 
@@ -1572,7 +1444,7 @@ void FAudio_INTERNAL_Mix_2in_2out_Scalar(
 		const float left = src[0] * totalVolumeL;
 		const float right = src[1] * totalVolumeR;
 
-		/* ... combined with the coefficients... */
+		/* ... combined with the coefficients. */
 		dst[0] += (
 			(left * coefficients[0]) +
 			(right * coefficients[1])
@@ -1581,18 +1453,6 @@ void FAudio_INTERNAL_Mix_2in_2out_Scalar(
 			(left * coefficients[2]) +
 			(right * coefficients[3])
 		);
-
-		/* ... then clamped. */
-		dst[0] = FAudio_clamp(
-			dst[0],
-			-FAUDIO_MAX_VOLUME_LEVEL,
-			FAUDIO_MAX_VOLUME_LEVEL
-		);
-		dst[1] = FAudio_clamp(
-			dst[1],
-			-FAUDIO_MAX_VOLUME_LEVEL,
-			FAUDIO_MAX_VOLUME_LEVEL
-		);
 	}
 }
 
@@ -1615,7 +1475,7 @@ void FAudio_INTERNAL_Mix_2in_6out_Scalar(
 		const float left = src[0] * totalVolumeL;
 		const float right = src[1] * totalVolumeR;
 
-		/* ... combined with the coefficients... */
+		/* ... combined with the coefficients. */
 		dst[0] += (
 			(left * coefficients[0]) +
 			(right * coefficients[1])
@@ -1640,38 +1500,6 @@ void FAudio_INTERNAL_Mix_2in_6out_Scalar(
 			(left * coefficients[10]) +
 			(right * coefficients[11])
 		);
-
-		/* ... then clamped. */
-		dst[0] = FAudio_clamp(
-			dst[0],
-			-FAUDIO_MAX_VOLUME_LEVEL,
-			FAUDIO_MAX_VOLUME_LEVEL
-		);
-		dst[1] = FAudio_clamp(
-			dst[1],
-			-FAUDIO_MAX_VOLUME_LEVEL,
-			FAUDIO_MAX_VOLUME_LEVEL
-		);
-		dst[2] = FAudio_clamp(
-			dst[2],
-			-FAUDIO_MAX_VOLUME_LEVEL,
-			FAUDIO_MAX_VOLUME_LEVEL
-		);
-		dst[3] = FAudio_clamp(
-			dst[3],
-			-FAUDIO_MAX_VOLUME_LEVEL,
-			FAUDIO_MAX_VOLUME_LEVEL
-		);
-		dst[4] = FAudio_clamp(
-			dst[4],
-			-FAUDIO_MAX_VOLUME_LEVEL,
-			FAUDIO_MAX_VOLUME_LEVEL
-		);
-		dst[5] = FAudio_clamp(
-			dst[5],
-			-FAUDIO_MAX_VOLUME_LEVEL,
-			FAUDIO_MAX_VOLUME_LEVEL
-		);
 	}
 }
 
@@ -1694,7 +1522,7 @@ void FAudio_INTERNAL_Mix_2in_8out_Scalar(
 		const float left = src[0] * totalVolumeL;
 		const float right = src[1] * totalVolumeR;
 
-		/* ... combined with the coefficients... */
+		/* ... combined with the coefficients. */
 		dst[0] += (
 			(left * coefficients[0]) +
 			(right * coefficients[1])
@@ -1727,48 +1555,6 @@ void FAudio_INTERNAL_Mix_2in_8out_Scalar(
 			(left * coefficients[14]) +
 			(right * coefficients[15])
 		);
-
-		/* ... then clamped. */
-		dst[0] = FAudio_clamp(
-			dst[0],
-			-FAUDIO_MAX_VOLUME_LEVEL,
-			FAUDIO_MAX_VOLUME_LEVEL
-		);
-		dst[1] = FAudio_clamp(
-			dst[1],
-			-FAUDIO_MAX_VOLUME_LEVEL,
-			FAUDIO_MAX_VOLUME_LEVEL
-		);
-		dst[2] = FAudio_clamp(
-			dst[2],
-			-FAUDIO_MAX_VOLUME_LEVEL,
-			FAUDIO_MAX_VOLUME_LEVEL
-		);
-		dst[3] = FAudio_clamp(
-			dst[3],
-			-FAUDIO_MAX_VOLUME_LEVEL,
-			FAUDIO_MAX_VOLUME_LEVEL
-		);
-		dst[4] = FAudio_clamp(
-			dst[4],
-			-FAUDIO_MAX_VOLUME_LEVEL,
-			FAUDIO_MAX_VOLUME_LEVEL
-		);
-		dst[5] = FAudio_clamp(
-			dst[5],
-			-FAUDIO_MAX_VOLUME_LEVEL,
-			FAUDIO_MAX_VOLUME_LEVEL
-		);
-		dst[6] = FAudio_clamp(
-			dst[6],
-			-FAUDIO_MAX_VOLUME_LEVEL,
-			FAUDIO_MAX_VOLUME_LEVEL
-		);
-		dst[7] = FAudio_clamp(
-			dst[7],
-			-FAUDIO_MAX_VOLUME_LEVEL,
-			FAUDIO_MAX_VOLUME_LEVEL
-		);
 	}
 }
 
